import request from '@/utils/request'

// 查询补卡记录列表
export function listRecord(query) {
  return request({
    url: '/system/record/list',
    method: 'get',
    params: query
  })
}

// 查询补卡记录详细
export function getRecord(id) {
  return request({
    url: '/system/record/' + id,
    method: 'get'
  })
}

// 新增补卡记录
export function addRecord(data) {
  return request({
    url: '/system/record',
    method: 'post',
    data: data
  })
}

// 修改补卡记录
export function updateRecord(data) {
  return request({
    url: '/system/record/put',
    method: 'post',
    data: data
  })
}

// 删除补卡记录
export function delRecord(id) {
  return request({
    url: '/system/record/delete/' + id,
    method: 'get'
  })
}
// 是否同意邀请
export function delInyq(data) {
  return request({
    url: '/system/record/putPass',
    method: 'post',
    data: data
  })
}
