<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-row class="last">
        <p><span>搜索条件</span> <i></i></p>
        <el-col :span="6">
          <el-form-item label="申请人" prop="userName">
            <el-input
              style="width: 180px;"
              v-model="queryParams.userName"
              placeholder="请输入申请人姓名"
              clearable
              @keyup.enter.native="handleQuery"
            />
          </el-form-item>
        </el-col>
        <el-col :span="6">
          <el-form-item label="申请时间" prop="applicationTime">
            <el-date-picker clearable
              v-model="queryParams.applicationTime"
              type="date"
              style="width: 180px;"
              value-format="yyyy-MM-dd"
              placeholder="请选择申请时间">
            </el-date-picker>
          </el-form-item>
        </el-col>
        <el-col :span="8">
          <el-form-item>
            <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
            <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
   <div class="navde">
     <el-row :gutter="10" class="mb8" style="background-color: #fafafa ;padding-top: 0;">
       <el-col :span="24">
         <div style="display: flex; align-items: center;justify-content: space-between;">
           <p style="border-left: 5px solid #3F73FD;padding-left: 5px;"><span>补卡记录</span> </p>
           <div>
         <el-button
           type="danger"
           plain
           size="mini"
           :disabled="multiple"
           @click="handleDelete"
           v-hasPermi="['system:record:remove']"
         >删除</el-button>
         <el-button
           type="primary"
           size="mini"
           @click="handleExport"
           v-hasPermi="['system:record:export']"
         >导出</el-button>
           </div>
         </div>
       </el-col>


       <!-- <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar> -->
     </el-row>
     <el-table :max-height="tableMaxHeight" v-loading="loading" :data="recordList" @selection-change="handleSelectionChange">
       <el-table-column type="selection" width="55" align="center" />
       <el-table-column label="部门名称" align="center" prop="deptName" />
       <el-table-column label="申请人姓名" align="center" prop="userName" />
       <el-table-column label="申请时间" align="center" prop="applicationTime" width="180">
         <template slot-scope="scope">
           <span>{{ scope.row.applicationTime}}</span>
         </template>
       </el-table-column>
       <el-table-column label="补卡理由" align="center" prop="reason" />
       <!-- <el-table-column label="审批人员姓名" align="center" prop="examinersName" /> -->
       <el-table-column label="是否通过" align="center" prop="isPass">
         <template slot-scope="scope">
           <dict-tag :options="dict.type.sys_card_result" :value="scope.row.isPass"/>
         </template>
       </el-table-column>
       <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
         <template slot-scope="scope">
           <el-button
             size="mini"
             type="text"
             v-if="scope.row.isPass==0"
             v-hasPermi="['system:record:putPass']"
             @click="handleTy(scope.row)"
           >同意</el-button>
           <el-button
             size="mini"
             type="text"
             v-if="scope.row.isPass==0"
             v-hasPermi="['system:record:putPass']"
             @click="handleJj(scope.row)"
           >驳回</el-button>
           <el-button
             size="mini"
             type="text"
             v-if="scope.row.isPass==0"
             @click="handleDelete(scope.row)"
             v-hasPermi="['system:record:remove']"
           >删除</el-button>
         </template>
       </el-table-column>
     </el-table>

     <pagination
       v-show="total>0"
       :total="total"
       :page.sync="queryParams.pageNum"
       :limit.sync="queryParams.pageSize"
       @pagination="getList"
     />
   </div>


    <!-- 添加或修改补卡记录对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listRecord, getRecord, delRecord, addRecord, updateRecord, delInyq } from "@/api/kaoqin/records";

export default {
  name: "Record",
  dicts: ['sys_card_result'],
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 补卡记录表格数据
      recordList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        userName: null,
        applicationTime: null,
        reason: null,
        examinersName: null,
        isPass: null
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
      },
      tableMaxHeight:'200'
    };
  },
  created() {
    this.getList();
    window.onresize = () => {
          this.changeTableMaxHeight()
        }
        this.changeTableMaxHeight()
  },
  methods: {
    /** 查询补卡记录列表 */
    getList() {
      this.loading = true;
      listRecord(this.queryParams).then(response => {
        this.recordList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        userId: null,
        userName: null,
        deptId: null,
        applicationTime: null,
        reason: null,
        examinersId: null,
        examinersName: null,
        isPass: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加补卡记录";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getRecord(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改补卡记录";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateRecord(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addRecord(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除补卡记录编号为"' + ids + '"的数据项？').then(function() {
        return delRecord(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/record/export', {
        ...this.queryParams
      }, `record_${new Date().getTime()}.xlsx`)
    },
    // 同意
    handleTy(row){
      const ids = row.id || this.ids;
      let nhdes = {
        id:ids,
        isPass:2,
        kaSort:row.kaSort
        }
      this.$modal.confirm('此操作将同意申请, 是否继续？').then(function() {
        return delInyq(nhdes);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("操作成功");
      }).catch(() => {});
    },
    // 拒绝
    handleJj(row){
     const ids = row.id || this.ids;
     let nhdes = {
       id:ids,
       isPass:1,
       kaSort:row.kaSort
       }
     this.$modal.confirm('此操作将拒绝申请, 是否继续？').then(function() {
       return delInyq(nhdes);
     }).then(() => {
       this.getList();
       this.$modal.msgSuccess("操作成功");
     }).catch(() => {});
    },
    // 获取屏幕高度
    showFilterForm () {
          this.filterActive = !this.filterActive
          this.changeTableMaxHeight()
        },
        changeTableMaxHeight () {
          let height = document.body.offsetHeight // 网页可视区域高度
          // if (this.filterActive) {
          //   this.tableMaxHeight = height - 320
          // } else {
            this.tableMaxHeight = height - 250
          // }
          console.log(height)
        }

  }
};
</script>
